==> kadaster-gds2-1.1-sources.jar: nl/logius/digikoppeling/gb/_2010/_10/ExternalDataReference.java <==

package nl.logius.digikoppeling.gb._2010._10;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for external-data-reference complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="external-data-reference">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="data-reference" type="{http://www.logius.nl/digikoppeling/gb/2010/10}data-reference" maxOccurs="unbounded"/>
 *       &lt;/sequence>
 *       &lt;attribute name="profile" type="{http://www.logius.nl/digikoppeling/gb/2010/10}gb-profile" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "external-data-reference", propOrder = {
    "dataReference"
})
public class ExternalDataReference {

    @XmlElement(name = "data-reference", required = true)
    protected List<DataReference> dataReference;
    @XmlAttribute(name = "profile")
    protected GbProfile profile;

    /**
     * Gets the value of the dataReference property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the dataReference property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getDataReference().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link DataReference }
     * 
     * 
     */
    public List<DataReference> getDataReference() {
        if (dataReference == null) {
            dataReference = new ArrayList<DataReference>();
        }
        return this.dataReference;
    }

    /**
     * Gets the value of the profile property.
     * 
     * @return
     *     possible object is
     *     {@link GbProfile }
     *     
     */
    public GbProfile getProfile() {
        return profile;
    }

    /**
     * Sets the value of the profile property.
     * 
     * @param value
     *     allowed object is
     *     {@link GbProfile }
     *     
     */
    public void setProfile(GbProfile value) {
        this.profile = value;
    }

}

==> kadaster-gds2-2.2-sources.jar: nl/logius/digikoppeling/gb/_2010/_10/ExternalDataReference.java <==

package nl.logius.digikoppeling.gb._2010._10;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * &lt;p&gt;Java class for external-data-reference complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="external-data-reference"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element name="data-reference" type="{http://www.logius.nl/digikoppeling/gb/2010/10}data-reference" maxOccurs="unbounded"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *       &amp;lt;attribute name="profile" type="{http://www.logius.nl/digikoppeling/gb/2010/10}gb-profile" /&amp;gt;
 *     &amp;lt;/restriction&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "external-data-reference", propOrder = {
    "dataReference"
})
public class ExternalDataReference {

    @XmlElement(name = "data-reference", required = true)
    protected List<DataReference> dataReference;
    @XmlAttribute(name = "profile")
    protected GbProfile profile;

    /**
     * Gets the value of the dataReference property.
     * 
     * &lt;p&gt;
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a &lt;CODE&gt;set&lt;/CODE&gt; method for the dataReference property.
     * 
     * &lt;p&gt;
     * For example, to add a new item, do as follows:
     * &lt;pre&gt;
     *    getDataReference().add(newItem);
     * &lt;/pre&gt;
     * 
     * 
     * &lt;p&gt;
     * Objects of the following type(s) are allowed in the list
     * {@link DataReference }
     * 
     * 
     */
    public List<DataReference> getDataReference() {
        if (dataReference == null) {
            dataReference = new ArrayList<DataReference>();
        }
        return this.dataReference;
    }

    /**
     * Gets the value of the profile property.
     * 
     * @return
     *     possible object is
     *     {@link GbProfile }
     *     
     */
    public GbProfile getProfile() {
        return profile;
    }

    /**
     * Sets the value of the profile property.
     * 
     * @param value
     *     allowed object is
     *     {@link GbProfile }
     *     
     */
    public void setProfile(GbProfile value) {
        this.profile = value;
    }

}
